<?php
/**
 * Prefs.inc.php
 * code by strangecode :: www.strangecode.com :: this document contains copyrighted information
 *
 * Prefs:: provides an API for saving arbitrary values in a user's session.
 *
 * @author  Quinn Comendant <quinn@strangecode.com>
 * @version 2.1
 */
class Prefs {

    // Namespace of preferences.
    var $ns;

    /**
     * Prefs constructor.
     */
    function Prefs($ns='')
    {
        $this->ns = '_pref_' . $ns;
        
        // Initialized the prefs array.
        if (!isset($_SESSION[$this->ns])) {
            $_SESSION[$this->ns] = array();
        }
    }

    /**
     * Sets the default value of a preference. The pref will be set only if
     * is not set already.
     *
     * @param  string $key       The name of the preference to modify.
     * @param  string $val       The new value for this preference.
     */
    function default($key, $val)
    {
        // Set it only if not set already.
        if (!isset($_SESSION[$this->ns][$key])) {
            $_SESSION[$this->ns][$key] = $val;
        }
    }

    /**
     * Sets the given preferences to the specific value,
     *
     * @param  string $key       The name of the preference to modify.
     * @param  string $val       The new value for this preference.
     */
    function set($key, $val)
    {
        $_SESSION[$this->ns][$key] = $val;
    }

    /**
     * Returns the value of the requested preference.
     *
     * @param string $key       The name of the preference to retrieve.
     *
     * @return string           The value of the preference.
     */
    function get($key)
    {
        return (isset($_SESSION[$this->ns][$key])) ? $_SESSION[$this->ns][$key] : null;
    }

    /**
     * To see if a preference has been set.
     *
     * @param string $key       The name of the preference to check.
     *
     * @return boolean          True if the preference isset and not empty
     *                          false otherwise.
     */
    function exists($key)
    {
        return isset($_SESSION[$this->ns][$key]);
    }

    /**
     * Clear a set preference value.
     *
     * @param string $key       The name of the preference to check.
     */
    function delete($key)
    {
        if (isset($_SESSION[$this->ns][$key])) {
            unset($_SESSION[$this->ns][$key]);
        }
    }

    /**
     * Perform cleanup operations.
     */
    function clear()
    {
        $_SESSION[$this->ns] = array();
    }
}


?>